@@ -1,20 +1,18 @@
-#' create_CCP_lcps
+#' Calculate Cumulative Cost Paths from Radial Locations
 #'
-#' Calculates Cumulative Cost Paths from Radial Locations
+#' Calculates Least Cost Paths from radial locations of a specified distance to the centre location. This is based on the method proposed by Verhagen (2013).
 #'
-#' Computes Least Cost Paths from radial locations of a specified distance to the centre location. This is based on the method proposed by Verhagen (2013).
+#' @param cost_surface \code{TransitionLayer} (gdistance package). Cost surface to be used in Least Cost Path calculation
 #'
-#' @param cost_surface \code{TransitionLayer} object (gdistance package). Cost surface to be used in Least Cost Path calculation
-#'
-#' @param location \code{SpatialPoints}. Location to which the Least Cost Paths are calculated to. Only the first row is taken into account
+#' @param location \code{SpatialPoints} (sp package). Location to which the Least Cost Paths are calculated to. Only the first row is taken into account
 #'
 #' @param distance \code{numeric} value. Distance from centre location to the radial locations
 #'
 #' @param radial_points \code{numeric} value. Number of radial locations around centre location
 #'
-#' @param cost_distance if TRUE computes total accumulated cost for each Least Cost Path. Default is FALSE
+#' @param cost_distance \code{logical}. if TRUE computes total accumulated cost for each Least Cost Path. Default is FALSE
 #'
-#' @param parallel if TRUE, the Least Cost Paths will be calculated in parallel. Number of Parallel socket clusters is total number of cores available minus 1. Default is FALSE
+#' @param parallel \code{logical}. if TRUE, the Least Cost Paths will be calculated in parallel. Number of Parallel socket clusters is total number of cores available minus 1. Default is FALSE
 #'
 #' @return \code{SpatialLinesDataFrame} (sp package). The resultant object contains least cost paths (number of LCPs is dependent on radial_points argument) calculated from radial locations to a centre location within a specified distance.
 #'
@@ -50,7 +48,7 @@ create_CCP_lcps <- function(cost_surface, location, distance, radial_points, cos
     }
     
     if (!inherits(location, c("SpatialPoints", "SpatialPointsDataFrame"))) {
-        stop("Location argument is invalid. Expecting SpatialPoints or SpatialPointsDataFrame object")
+        stop("Location argument is invalid. Expecting SpatialPoints* object")
     }
     
     if (!inherits(distance, "numeric")) {
