@@ -1,18 +1,16 @@
-#' create_FETE_lcps
+#' Calculate least cost paths from each location to all other locations.
 #'
-#' Calculates least cost paths from each location to all other locations.
+#' Calculates least cost paths from each location to all other locations (i.e. From Everywhere To Everywhere (FETE)). This is based on the method proposed by White and Barber (2012).
 #'
-#' Computes least cost paths from each location to all other locations (i.e. From Everywhere To Everywhere (FETE)). This is based on the method proposed by White and Barber (2012).
+#' @param cost_surface \code{TransitionLayer} (gdistance package). Cost surface to be used in Least Cost Path calculation
 #'
-#' @param cost_surface \code{TransitionLayer} object (gdistance package). Cost surface to be used in Least Cost Path calculation.
+#' @param locations \code{SpatialPoints*} (sp package). Locations to calculate Least Cost Paths from and to
 #'
-#' @param locations \code{SpatialPoints}. Locations to calculate Least Cost Paths from and to.
+#' @param cost_distance \code{logical}. if TRUE computes total accumulated cost for each Least Cost Path. Default is FALSE
 #'
-#' @param cost_distance if TRUE computes total accumulated cost for each Least Cost Path. Default is FALSE.
+#'@param parallel \code{logical}. if TRUE the Least Cost Paths will be calculated in parallel. Number of Parallel socket clusters is total number of cores available minus 1. Default is FALSE
 #'
-#'@param parallel if TRUE, the Least Cost Paths will be calculated in parallel. Number of Parallel socket clusters is total number of cores available minus 1. Default is FALSE.
-#'
-#' @return \code{SpatialLinesDataFrame} (sp package). The resultant object contains least cost paths calculated from each location to all other locations.
+#' @return \code{SpatialLinesDataFrame} (sp package). The resultant object contains least cost paths calculated from each location to all other locations
 #'
 #' @author Joseph Lewis
 #'
@@ -47,7 +45,7 @@ create_FETE_lcps <- function(cost_surface, locations, cost_distance = FALSE, par
     }
     
     if (!inherits(locations, c("SpatialPoints", "SpatialPointsDataFrame"))) {
-        stop("Locations argument is invalid. Expecting SpatialPoints or SpatialPointsDataFrame object")
+        stop("Locations argument is invalid. Expecting SpatialPoints* object")
     }
     
     if (length(locations) < 2) 
